@@ -3,24 +3,20 @@ An HTTP test running. Call http_test with the filename
 of a YAML file containing tests and a base_url for the
 test server.
 """
-import os
 
-import httplib2
-import simplejson
-
-from base64 import b64encode
-from re import match
-
-from fixtures import muchdata, reset_textstore, _teststore, initialize_app
+from .fixtures import (muchdata, reset_textstore, _teststore, initialize_app,
+        get_http)
 
 from tiddlyweb.model.user import User
 
-tests = store = http = None
+tests = store = base_url = None
+http = get_http()
 
 __all__ = ('http_test', 'test_assert_response', 'test_the_TESTS')
 
+
 def http_test(test_data, base):
-    global tests, store, http, base_url
+    global tests, store, base_url
     base_url = base
     tests = test_data
     initialize_app()
@@ -33,7 +29,6 @@ def http_test(test_data, base):
     user = User('cdent')
     user.set_password('cowpig')
     store.put(user)
-    http = httplib2.Http()
 
 
 def test_assert_response():
@@ -76,17 +71,25 @@ def test_the_TESTS():
         test.update(test_data)
         yield test['name'], _run_test, test
 
+
 def _run_test(test):
     full_url = base_url + test['url']
     if test['method'] == 'GET' or test['method'] == 'DELETE':
-        response, content = http.request(full_url, method=test['method'], headers=test['request_headers'])
+        response, content = http.requestU(full_url,
+                method=test['method'],
+                headers=test['request_headers'])
     else:
-        response, content = http.request(full_url, method=test['method'], headers=test['request_headers'],
+        response, content = http.requestU(full_url,
+                method=test['method'],
+                headers=test['request_headers'],
                 body=test['data'].encode('UTF-8'))
-    assert_response(response, content, test['status'], headers=test['response_headers'], expected=test['expected'])
+    assert_response(response, content, test['status'],
+            headers=test['response_headers'], expected=test['expected'])
+
 
 def assert_response(response, content, status, headers=None, expected=None):
-    if response['status'] == '500': print content
+    if response['status'] == '500':
+        print(content)
     assert response['status'] == '%s' % status, (response, content)
 
     if headers:
@@ -95,4 +98,5 @@ def assert_response(response, content, status, headers=None, expected=None):
 
     if expected:
         for expect in expected:
-            assert expect.encode('UTF-8') in content
+            #assert expect.encode('UTF-8') in content
+            assert expect in content
