@@ -59,7 +59,7 @@ class Collection(object):
         """
         Update the digest with this thing.
         """
-        self._digest.update(thing)
+        self._digest.update(thing.encode('utf-8'))
 
     def hexdigest(self):
         """
@@ -132,7 +132,7 @@ class Tiddlers(Collection):
             if not tiddler.store and self.store:
                 try:
                     tiddler = self.store.get(tiddler)
-                except StoreError, exc:
+                except StoreError as exc:
                     LOGGER.debug('missed tiddler in collection: %s, %s',
                             tiddler, exc)
                     continue
@@ -149,7 +149,7 @@ class Tiddlers(Collection):
         if not tiddler.store and self.store:
             try:
                 tiddler = self.store.get(tiddler)
-            except StoreError, exc:
+            except StoreError as exc:
                 LOGGER.debug(
                         'tried to add missing tiddler to collection: %s, %s',
                         tiddler, exc)
@@ -181,4 +181,4 @@ class Tiddlers(Collection):
         except AttributeError:
             pass
         self._digest.update(tiddler.title.encode('utf-8'))
-        self._digest.update(str(tiddler.revision))
+        self._digest.update(str(tiddler.revision).encode('utf-8'))
